DefaultDropDown<T> class

A DefaultDropDown widget to display a list of options in a dropdown fashion.

This widget is the default implementation of a dropdown menu for the SearchAutocomplete widget. It displays a list of options and informs when an option is selected.

Constructor Parameters:

  • options: A list of generic type options that will populate the dropdown.
  • onSelected: A function that fires when an item is selected from the dropdown.
  • getString: A function that takes an item of generic type T and returns its String representation.
Inheritance

Constructors

DefaultDropDown({Key? key, required List<T> options, required ValueChanged<T> onSelected, required String getString(T)})
Creates a DefaultDropDown widget.
const

Properties

getString String Function(T)
Function to transform an option object to its string representation.
final
hashCode int
The hash code for this object.
no setterinherited
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
onSelected ValueChanged<T>
Callback function that fires when an item is selected from the dropdown.
final
options List<T>
A list of options to be displayed in the dropdown.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

build(BuildContext context) Widget
Describes the part of the user interface represented by this widget.
override
createElement() StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited