controller property

TextEditingController controller
final

The TextEditingController that controls the text field.

It holds the current value of the text field and notifies the listeners when there is a change.

Implementation

final TextEditingController controller;