getString property

String Function(T) getString
final

Function to transform an option object to its string representation.

This function is used to convert the generic type options to string to be displayed in the search field and dropdown.

Implementation

final String Function(T) getString;