hintText property
An optional placeholder text for the search field.
If this is null, no placeholder will be displayed.
Implementation
final String? hintText;
An optional placeholder text for the search field.
If this is null, no placeholder will be displayed.
final String? hintText;